@@ -2,7 +2,7 @@
 #
 #       clipboard.py
 #
-#       Copyright 2009-2011 Giuseppe Penone <giuspen@gmail.com>
+#       Copyright 2009-2012 Giuseppe Penone <giuspen@gmail.com>
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -300,9 +300,11 @@ class ClipboardHandler:
             pixbuf = gtk.gdk.pixbuf_new_from_file(cons.ANCHOR_CHAR)
             pixbuf.anchor = dom_node.attributes["anchor"].value
         else: pixbuf = machines.get_pixbuf_from_encoded_buffer(dom_node.firstChild.data)
-        self.dad.image_insert(self.dad.curr_buffer.get_iter_at_mark(self.dad.curr_buffer.get_insert()),
-                              pixbuf,
-                              justification)
+        if pixbuf:
+            self.dad.image_insert(self.dad.curr_buffer.get_iter_at_mark(self.dad.curr_buffer.get_insert()),
+                                  pixbuf,
+                                  image_justification=justification,
+                                  text_buffer=self.dad.curr_buffer)
 
     def to_codebox(self, clipboard, selectiondata, data):
         """From Clipboard to CodeBox"""
@@ -327,7 +329,8 @@ class ClipboardHandler:
         }
         self.dad.codeboxes_handler.codebox_insert(self.dad.curr_buffer.get_iter_at_mark(self.dad.curr_buffer.get_insert()),
                                                   codebox_dict,
-                                                  justification)
+                                                  codebox_justification=justification,
+                                                  text_buffer=self.dad.curr_buffer)
 
     def to_table(self, clipboard, selectiondata, table_model_n_iter):
         """From Clipboard to Table"""
@@ -360,7 +363,8 @@ class ClipboardHandler:
             # insert new table
             self.dad.tables_handler.table_insert(self.dad.curr_buffer.get_iter_at_mark(self.dad.curr_buffer.get_insert()),
                                                  table,
-                                                 justification)
+                                                 table_justification=justification,
+                                                 text_buffer=self.dad.curr_buffer)
         else:
             # paste into existing table
             (model, iter) = table_model_n_iter
@@ -371,11 +375,16 @@ class ClipboardHandler:
                     elif len(table_row) < num_columns: table_row = table_row + [""]*(num_columns - len(table_row))
                     iter = model.insert_after(iter, table_row)
 
-    def rich_text_get_from_text_buffer_selection(self, text_buffer, iter_sel_start, iter_sel_end, change_case="n"):
+    def rich_text_get_from_text_buffer_selection(self, text_buffer, iter_sel_start, iter_sel_end,
+                                                 change_case="n", exclude_iter_sel_end=False):
         """Given text_buffer and selection, returns the rich text xml"""
+        iter_sel_start_offset = iter_sel_start.get_offset()
+        iter_sel_end_offset = iter_sel_end.get_offset()
+        if exclude_iter_sel_end: iter_sel_end_offset -= 1
+        iter_sel_range = (iter_sel_start_offset, iter_sel_end_offset)
         pixbuf_table_codebox_vector = self.dad.state_machine.get_embedded_pixbufs_tables_codeboxes(text_buffer,
                                                                                                    for_print=0,
-                                                                                                   sel_range=(iter_sel_start.get_offset(), iter_sel_end.get_offset()))
+                                                                                                   sel_range=iter_sel_range)
         # pixbuf_table_codebox_vector is [ [ "pixbuf"/"table"/"codebox", [offset, pixbuf, alignment] ],... ]
         dom = xml.dom.minidom.Document()
         root = dom.createElement("root")
@@ -406,7 +415,8 @@ class ClipboardHandler:
         tag_found = curr_iter.forward_to_tag_toggle(None)
         while tag_found:
             if curr_iter.get_offset() > end_offset: curr_iter = text_buffer.get_iter_at_offset(end_offset)
-            self.dad.xml_handler.rich_text_serialize(dom_iter, start_iter, curr_iter, self.curr_attributes, change_case)
+            self.dad.xml_handler.rich_txt_serialize(dom_iter, start_iter, curr_iter, self.curr_attributes,
+                                                    change_case=change_case, dom=dom)
             offset_old = curr_iter.get_offset()
             if offset_old >= end_offset: break
             else:
@@ -416,7 +426,8 @@ class ClipboardHandler:
                 if curr_iter.get_offset() == offset_old: break
         else:
             if curr_iter.get_offset() > end_offset: curr_iter = text_buffer.get_iter_at_offset(end_offset)
-            self.dad.xml_handler.rich_text_serialize(dom_iter, start_iter, curr_iter, self.curr_attributes, change_case)
+            self.dad.xml_handler.rich_txt_serialize(dom_iter, start_iter, curr_iter, self.curr_attributes,
+                                                    change_case=change_case, dom=dom)
         if obj_element:
             if obj_element[0] == "pixbuf": self.dad.xml_handler.pixbuf_element_to_xml(obj_element[1], dom_iter, dom)
             elif obj_element[0] == "table": self.dad.xml_handler.table_element_to_xml(obj_element[1], dom_iter)
