@@ -404,8 +404,8 @@ class CTDBHandler:
         """Read a node content from DB"""
         if self.dad.user_active:
             self.dad.user_active = False
-            back_to_user_active = True
-        else: back_to_user_active = False
+            user_active_restore = True
+        else: user_active_restore = False
         syntax_highlighting = self.dad.treestore[tree_iter][4]
         if original_id: node_id = original_id
         else: node_id = self.dad.treestore[tree_iter][3]
@@ -467,7 +467,7 @@ class CTDBHandler:
                     else: self.add_node_image(images_rows[obj_idx[1]], curr_buffer)
                 self.dad.sourceview.set_buffer(self.dad.curr_buffer)
         curr_buffer.set_modified(False)
-        if back_to_user_active: self.dad.user_active = True
+        if user_active_restore: self.dad.user_active = True
     
     def get_children_rows_from_father_id(self, db, father_id):
         """Returns the children rows given the father_id"""
