@@ -2,7 +2,7 @@
 #
 #       exports.py
 #
-#       Copyright 2009-2011 Giuseppe Penone <giuspen@gmail.com>
+#       Copyright 2009-2012 Giuseppe Penone <giuspen@gmail.com>
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -30,42 +30,57 @@ class Export2CTD:
         """Export to Txt boot"""
         self.dad = dad
 
-    def get_single_ctd_filepath(self, proposed_name, filter_pattern):
+    def get_single_ct_filepath(self, filename_hint):
         """Prepare for the CTD file save"""
-        filepath = support.dialog_file_save_as(proposed_name,
-                                               filter_pattern=filter_pattern,
+        filepath = support.dialog_file_save_as(filename_hint,
+                                               filter_pattern="*.ct*",
                                                filter_name=_("CherryTree Document"),
                                                curr_folder=self.dad.file_dir,
                                                parent=self.dad.window)
-        if filepath == None: return None
-        return self.dad.filepath_extension_fix(filepath)
+        if filepath: filepath = self.dad.filepath_extension_fix(filepath)
+        return filepath
 
     def nodes_all_export_to_ctd(self, filepath):
         """Export All Nodes To CTD"""
-        try: xml_string = self.dad.xml_handler.treestore_to_dom()
+        if self.dad.filetype in ["d", "z"]:
+            try: xml_string = self.dad.xml_handler.treestore_to_dom()
+            except:
+                support.dialog_error("%s write failed - all nodes to xml" % filepath, self.dad.window)
+                raise
+                return
+        else: xml_string = ""
+        try: self.dad.file_write_low_level(filepath, xml_string, first_write=True, exporting="a")
         except:
-            support.dialog_error("%s write failed - all nodes to xml" % filepath, self.dad.window)
-            return
-        try: self.dad.file_write_low_level(filepath, xml_string)
-        except: support.dialog_error("%s write failed - writing to disk" % filepath, self.dad.window)
+            support.dialog_error("%s write failed - writing to disk" % filepath, self.dad.window)
+            raise
 
     def node_and_subnodes_export_to_ctd(self, tree_iter, filepath):
         """Export Node and Subnodes To CTD"""
-        try: xml_string = self.dad.xml_handler.treestore_sel_node_and_subnodes_to_dom(tree_iter)
+        if self.dad.filetype in ["d", "z"]:
+            try: xml_string = self.dad.xml_handler.treestore_sel_node_and_subnodes_to_dom(tree_iter)
+            except:
+                support.dialog_error("%s write failed - sel node and subnodes to xml" % filepath, self.dad.window)
+                raise
+                return
+        else: xml_string = ""
+        try: self.dad.file_write_low_level(filepath, xml_string, first_write=True, exporting="s")
         except:
-            support.dialog_error("%s write failed - sel node and subnodes to xml" % filepath, self.dad.window)
-            return
-        try: self.dad.file_write_low_level(filepath, xml_string)
-        except: support.dialog_error("%s write failed - writing to disk" % filepath, self.dad.window)
+            support.dialog_error("%s write failed - writing to disk" % filepath, self.dad.window)
+            raise
 
     def node_export_to_ctd(self, tree_iter, filepath):
         """Export the Selected Node To CTD"""
-        try: xml_string = self.dad.xml_handler.treestore_sel_node_only_to_dom(tree_iter)
+        if self.dad.filetype in ["d", "z"]:
+            try: xml_string = self.dad.xml_handler.treestore_sel_node_only_to_dom(tree_iter)
+            except:
+                support.dialog_error("%s write failed - sel node to xml" % filepath, self.dad.window)
+                raise
+                return
+        else: xml_string = ""
+        try: self.dad.file_write_low_level(filepath, xml_string, first_write=True, exporting="n")
         except:
-            support.dialog_error("%s write failed - sel node to xml" % filepath, self.dad.window)
-            return
-        try: self.dad.file_write_low_level(filepath, xml_string)
-        except: support.dialog_error("%s write failed - writing to disk" % filepath, self.dad.window)
+            support.dialog_error("%s write failed - writing to disk" % filepath, self.dad.window)
+            raise
 
 
 class ExportPrint:
@@ -87,10 +102,12 @@ class ExportPrint:
             self.nodes_all_export_print_iter(tree_iter)
             if top_tree_iter: break
             tree_iter = self.dad.treestore.iter_next(tree_iter)
+        self.dad.objects_buffer_refresh()
         self.run_print()
 
     def nodes_all_export_print_iter(self, tree_iter):
         """Export Print All Nodes - Iter"""
+        self.dad.get_textbuffer_from_tree_iter(tree_iter)
         if self.dad.treestore[tree_iter][4] == cons.CUSTOM_COLORS_ID:
             pango_text, pixbuf_table_codebox_vector = self.pango_handler.pango_get_from_treestore_node(tree_iter)
             self.text_font = self.dad.text_font # text font for all (also eventual code nodes)
@@ -165,10 +182,11 @@ class Export2Txt:
             self.nodes_all_export_to_txt_iter(tree_iter)
             if top_tree_iter: break
             tree_iter = self.dad.treestore.iter_next(tree_iter)
+        self.dad.objects_buffer_refresh()
 
     def nodes_all_export_to_txt_iter(self, tree_iter):
         """Export All Nodes To Txt - iter"""
-        text_buffer = self.dad.treestore[tree_iter][2]
+        text_buffer = self.dad.get_textbuffer_from_tree_iter(tree_iter)
         filepath = os.path.join(self.new_path,
                                 support.get_node_hierarchical_name(self.dad, tree_iter) + ".txt")
         self.node_export_to_txt(text_buffer, filepath)
@@ -338,6 +356,7 @@ class Export2Html:
             if top_tree_iter: break
             tree_iter = self.dad.treestore.iter_next(tree_iter)
         self.tree_links_text = ""
+        self.dad.objects_buffer_refresh()
 
     def nodes_all_export_to_html_iter(self, tree_iter):
         """Export All Nodes To HTML - iter"""
@@ -352,7 +371,7 @@ class Export2Html:
         href = self.get_html_filename(tree_iter)
         self.tree_links_text += "<tr><td>"
         self.tree_links_text += "&nbsp;&nbsp;&nbsp;" * len(self.tree_links_nums)
-        icon_rel_path = os.path.join(self.images_dir, cons.STOCKS_N_FILES[self.dad.treestore[tree_iter][0]])
+        icon_rel_path = os.path.join("images", cons.STOCKS_N_FILES[self.dad.treestore[tree_iter][0]])
         self.tree_links_text += '<img src="%s" alt="%s" height="22" width="22"/>' % (icon_rel_path, icon_rel_path)
         self.tree_links_text += '<a href="' + href + '">' + ".".join(self.tree_links_nums) + " " + self.dad.treestore[tree_iter][1] + "</a></td></tr>"
         child_tree_iter = self.dad.treestore.iter_children(tree_iter)
@@ -373,13 +392,14 @@ class Export2Html:
         file_descriptor.close()
 
     def node_export_to_html(self, tree_iter):
-        """Export the Selected Node To HTML"""
+        """Export a Node To HTML"""
         html_text = cons.HTML_HEADER % self.dad.treestore[tree_iter][1]
         if self.tree_links_text:
             html_text += r'<table width="100%"><tr>'
             td_tree = r'<td valign="top" align="left" width=30%>'
             td_page = r'<td valign="top" align="left" width=70%>'
             html_text += td_tree + self.tree_links_text + td_page
+        self.dad.get_textbuffer_from_tree_iter(tree_iter)
         if self.dad.treestore[tree_iter][4] == cons.CUSTOM_COLORS_ID:
             text_n_objects = self.html_get_from_treestore_node(tree_iter)
             self.images_count = 0
@@ -440,7 +460,7 @@ class Export2Html:
         self.images_count += 1
         if tree_iter:
             image_name = "%s-%s.png" % (self.dad.treestore[tree_iter][3], self.images_count)
-            image_rel_path = os.path.join(self.images_dir, image_name)
+            image_rel_path = os.path.join("images", image_name)
         else:
             image_name = "%s.png" % self.images_count
             image_rel_path = "file://" + os.path.join(self.images_dir, image_name)
