@@ -31,6 +31,7 @@ class FindReplace:
         """Lists Handler boot"""
         self.dad = dad
         self.replace_active = False
+        self.replace_subsequent = False
         self.curr_find = [None, ""] # [latest find type, latest find pattern]
         self.from_find_iterated = False
         self.from_find_back = False
@@ -54,7 +55,9 @@ class FindReplace:
         elif response == 2:
             # replace
             self.replace_active = True
+            self.replace_subsequent = True
             self.find_again()
+            self.replace_subsequent = False
         elif response == 3:
             # undo replace
             self.dad.requested_step_back()
@@ -146,6 +149,10 @@ class FindReplace:
         if all_matches: self.liststore_create_or_clean()
         config.get_tree_expanded_collapsed_string(self.dad)
         # searching start
+        if self.dad.user_active:
+            self.dad.user_active = False
+            user_active_restore = True
+        else: user_active_restore = False
         while node_iter:
             self.all_matches_first_in_node = True
             while self.parse_given_node_content(node_iter, pattern, forward, first_fromsel, all_matches):
@@ -183,6 +190,7 @@ class FindReplace:
                 self.dad.sourceview.scroll_to_mark(self.dad.curr_buffer.get_insert(), 0.3)
                 if self.dad.glade.checkbutton_iterated_find_dialog.get_active():
                     self.iterated_find_dialog()
+        if user_active_restore: self.dad.user_active = True
 
     def find_a_node(self, *args):
         """Search for a pattern between all the Node's Names"""
@@ -314,7 +322,7 @@ class FindReplace:
                     self.dad.set_selection_at_offset_n_delta(match_offsets[0] + num_objs,
                                                              len(replacer_text))
                 self.dad.state_machine.update_state(self.dad.treestore[self.dad.curr_tree_iter][3])
-                self.ctdb_handler.pending_edit_db_node_buff(self.dad.treestore[self.dad.curr_tree_iter][3])
+                self.dad.ctdb_handler.pending_edit_db_node_buff(self.dad.treestore[self.dad.curr_tree_iter][3])
             return True
         else: return False
     
@@ -368,8 +376,8 @@ class FindReplace:
         or (all_matches and not self.all_matches_first_in_node):
             iter_insert = self.dad.curr_buffer.get_iter_at_mark(self.dad.curr_buffer.get_insert())
             iter_bound = self.dad.curr_buffer.get_iter_at_mark(self.dad.curr_buffer.get_selection_bound())
-            if not self.replace_active:
-                # it's a find, so we want, given a selected word, to find for the subsequent one
+            if not self.replace_active or self.replace_subsequent:
+                # it's a find or subsequent replace, so we want, given a selected word, to find for the subsequent one
                 if forward:
                     if iter_bound != None and iter_insert.compare(iter_bound) < 0: start_iter = iter_bound
                     else: start_iter = iter_insert
@@ -377,7 +385,7 @@ class FindReplace:
                     if iter_bound != None and iter_insert.compare(iter_bound) > 0: start_iter = iter_bound
                     else: start_iter = iter_insert
             else:
-                # it's a replace, so we want, given a selected word, to replace starting from this one
+                # it's a first replace, so we want, given a selected word, to replace starting from this one
                 if forward:
                     if iter_bound != None and iter_insert.compare(iter_bound) > 0: start_iter = iter_bound
                     else: start_iter = iter_insert
@@ -484,8 +492,10 @@ class FindReplace:
     def replace_again(self):
         """Continue the previous replace (a_node/in_selected_node/in_all_nodes)"""
         self.replace_active = True
+        self.replace_subsequent = True
         self.find_again()
         self.replace_active = False
+        self.replace_subsequent = False
 
     def get_line_content(self, text_iter):
         """Returns the Line Content Given the Text Iter"""
